ErrorEvent

Struct ErrorEvent 

pub struct ErrorEvent {
    pub context: Option<ErrorContext>,
    pub event_time: Option<DateTime<Utc>>,
    pub message: Option<String>,
    pub service_context: Option<ServiceContext>,
}
An error event which is returned by the Error Reporting system.

This type is not used in any activity, and only used as part of another schema.

Fields

context: Option<ErrorContext>

Data about the context in which the error occurred.

event_time: Option<DateTime<Utc>>

Time when the event occurred as provided in the error report. If the report did not contain a timestamp, the time the error was received by the Error Reporting system is used.

message: Option<String>

The stack trace that was reported or logged by the service.

service_context: Option<ServiceContext>

The ServiceContext for which this error was reported.