ErrorGroupStats

Struct ErrorGroupStats 

pub struct ErrorGroupStats {
    pub affected_services: Option<Vec<ServiceContext>>,
    pub affected_users_count: Option<i64>,
    pub count: Option<i64>,
    pub first_seen_time: Option<DateTime<Utc>>,
    pub group: Option<ErrorGroup>,
    pub last_seen_time: Option<DateTime<Utc>>,
    pub num_affected_services: Option<i32>,
    pub representative: Option<ErrorEvent>,
    pub timed_counts: Option<Vec<TimedCount>>,
}
Data extracted for a specific group based on certain filter criteria, such as a given time period and/or service filter.

This type is not used in any activity, and only used as part of another schema.

Fields

affected_services: Option<Vec<ServiceContext>>

Service contexts with a non-zero error count for the given filter criteria. This list can be truncated if multiple services are affected. Refer to num_affected_services for the total count.

affected_users_count: Option<i64>

Approximate number of affected users in the given group that match the filter criteria. Users are distinguished by data in the ErrorContext of the individual error events, such as their login name or their remote IP address in case of HTTP requests. The number of affected users can be zero even if the number of errors is non-zero if no data was provided from which the affected user could be deduced. Users are counted based on data in the request context that was provided in the error report. If more users are implicitly affected, such as due to a crash of the whole service, this is not reflected here.

count: Option<i64>

Approximate total number of events in the given group that match the filter criteria.

first_seen_time: Option<DateTime<Utc>>

Approximate first occurrence that was ever seen for this group and which matches the given filter criteria, ignoring the time_range that was specified in the request.

group: Option<ErrorGroup>

Group data that is independent of the filter criteria.

last_seen_time: Option<DateTime<Utc>>

Approximate last occurrence that was ever seen for this group and which matches the given filter criteria, ignoring the time_range that was specified in the request.

num_affected_services: Option<i32>

The total number of services with a non-zero error count for the given filter criteria.

representative: Option<ErrorEvent>

An arbitrary event that is chosen as representative for the whole group. The representative event is intended to be used as a quick preview for the whole group. Events in the group are usually sufficiently similar to each other such that showing an arbitrary representative provides insight into the characteristics of the group as a whole.

timed_counts: Option<Vec<TimedCount>>

Approximate number of occurrences over time. Timed counts returned by ListGroups are guaranteed to be: - Inside the requested time interval - Non-overlapping, and - Ordered by ascending time.