TimedCount

Struct TimedCount 

pub struct TimedCount {
    pub count: Option<i64>,
    pub end_time: Option<DateTime<Utc>>,
    pub start_time: Option<DateTime<Utc>>,
}
The number of errors in a given time period. All numbers are approximate since the error events are sampled before counting them.

This type is not used in any activity, and only used as part of another schema.

Fields

count: Option<i64>

Approximate number of occurrences in the given time period.

end_time: Option<DateTime<Utc>>

End of the time period to which count refers (excluded).

start_time: Option<DateTime<Utc>>

Start of the time period to which count refers (included).